SelectedValueItemOptions<T> class
Constructors
- SelectedValueItemOptions({Color? backgroundColor, double? borderRadius, required String label, TextStyle? labelStyle, bool? showBorder = true, Color? borderColor, EdgeInsets? padding, Widget? icon})
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderRadius → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- label → String
-
final
- labelStyle → TextStyle?
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBorder → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited